@@ -1,4 +1,4 @@
-/* 
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,8 +18,6 @@
  */
 package org.apache.parquet.io;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.fail;
 import static org.apache.parquet.example.Paper.pr1;
 import static org.apache.parquet.example.Paper.pr2;
 import static org.apache.parquet.example.Paper.r1;
@@ -30,6 +28,8 @@ import static org.apache.parquet.schema.PrimitiveType.PrimitiveTypeName.BINARY;
 import static org.apache.parquet.schema.PrimitiveType.PrimitiveTypeName.INT32;
 import static org.apache.parquet.schema.Type.Repetition.OPTIONAL;
 import static org.apache.parquet.schema.Type.Repetition.REQUIRED;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.fail;
 
 import java.io.IOException;
 import java.util.ArrayList;
@@ -37,17 +37,10 @@ import java.util.Arrays;
 import java.util.Collection;
 import java.util.Iterator;
 import java.util.List;
-
-import org.apache.parquet.bytes.BytesInput;
-import org.apache.parquet.column.ParquetProperties;
-import org.junit.Assert;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
-
 import org.apache.parquet.column.ColumnDescriptor;
 import org.apache.parquet.column.ColumnWriteStore;
 import org.apache.parquet.column.ColumnWriter;
+import org.apache.parquet.column.ParquetProperties;
 import org.apache.parquet.column.impl.ColumnWriteStoreV1;
 import org.apache.parquet.column.page.PageReadStore;
 import org.apache.parquet.column.page.mem.MemPageStore;
@@ -67,6 +60,10 @@ import org.apache.parquet.schema.PrimitiveType;
 import org.apache.parquet.schema.PrimitiveType.PrimitiveTypeName;
 import org.apache.parquet.schema.Type;
 import org.apache.parquet.schema.Type.Repetition;
+import org.junit.Assert;
+import org.junit.Test;
+import org.junit.runner.RunWith;
+import org.junit.runners.Parameterized;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -74,46 +71,44 @@ import org.slf4j.LoggerFactory;
 public class TestColumnIO {
   private static final Logger LOG = LoggerFactory.getLogger(TestColumnIO.class);
 
-  private static final String oneOfEach =
-    "message Document {\n"
-  + "  required int64 a;\n"
-  + "  required int32 b;\n"
-  + "  required float c;\n"
-  + "  required double d;\n"
-  + "  required boolean e;\n"
-  + "  required binary f;\n"
-  + "  required int96 g;\n"
-  + "  required fixed_len_byte_array(3) h;\n"
-  + "}\n";
+  private static final String oneOfEach = "message Document {\n"
+      + "  required int64 a;\n"
+      + "  required int32 b;\n"
+      + "  required float c;\n"
+      + "  required double d;\n"
+      + "  required boolean e;\n"
+      + "  required binary f;\n"
+      + "  required int96 g;\n"
+      + "  required fixed_len_byte_array(3) h;\n"
+      + "}\n";
 
-  private static final String schemaString =
-      "message Document {\n"
-    + "  required int64 DocId;\n"
-    + "  optional group Links {\n"
-    + "    repeated int64 Backward;\n"
-    + "    repeated int64 Forward;\n"
-    + "  }\n"
-    + "  repeated group Name {\n"
-    + "    repeated group Language {\n"
-    + "      required binary Code;\n"
-    + "      optional binary Country;\n"
-    + "    }\n"
-    + "    optional binary Url;\n"
-    + "  }\n"
-    + "}\n";
+  private static final String schemaString = "message Document {\n"
+      + "  required int64 DocId;\n"
+      + "  optional group Links {\n"
+      + "    repeated int64 Backward;\n"
+      + "    repeated int64 Forward;\n"
+      + "  }\n"
+      + "  repeated group Name {\n"
+      + "    repeated group Language {\n"
+      + "      required binary Code;\n"
+      + "      optional binary Country;\n"
+      + "    }\n"
+      + "    optional binary Url;\n"
+      + "  }\n"
+      + "}\n";
 
   int[][] expectedFSA = new int[][] {
-      { 1 },      // 0: DocId
-      { 2, 1 },   // 1: Links.Backward
-      { 3, 2 },   // 2: Links.Forward
-      { 4, 4, 4 },// 3: Name.Language.Code
-      { 5, 5, 3 },// 4: Name.Language.Country
-      { 6, 3 }    // 5: Name.Url
+    {1}, // 0: DocId
+    {2, 1}, // 1: Links.Backward
+    {3, 2}, // 2: Links.Forward
+    {4, 4, 4}, // 3: Name.Language.Code
+    {5, 5, 3}, // 4: Name.Language.Country
+    {6, 3} // 5: Name.Url
   };
 
   int[][] expectedFSA2 = new int[][] {
-      { 1 },      // 0: DocId
-      { 2, 1, 1 },// 1: Name.Language.Country
+    {1}, // 0: DocId
+    {2, 1, 1}, // 1: Name.Language.Country
   };
 
   public static final String[] expectedEventsForR1 = {
@@ -148,9 +143,7 @@ public class TestColumnIO {
 
   @Parameterized.Parameters
   public static Collection<Object[]> data() throws IOException {
-    Object[][] data = {
-        { true },
-        { false } };
+    Object[][] data = {{true}, {false}};
     return Arrays.asList(data);
   }
 
@@ -166,84 +159,88 @@ public class TestColumnIO {
   }
 
   @Test
-  public void testReadUsingRequestedSchemaWithExtraFields(){
-    MessageType orginalSchema = new MessageType("schema",
-            new PrimitiveType(REQUIRED, INT32, "a"),
-            new PrimitiveType(OPTIONAL, INT32, "b")
-    );
-    MessageType schemaWithExtraField = new MessageType("schema",
-            new PrimitiveType(OPTIONAL, INT32, "b"),
-            new PrimitiveType(OPTIONAL, INT32, "a"),
-            new PrimitiveType(OPTIONAL, INT32, "c")
-    );
+  public void testReadUsingRequestedSchemaWithExtraFields() {
+    MessageType orginalSchema = new MessageType(
+        "schema", new PrimitiveType(REQUIRED, INT32, "a"), new PrimitiveType(OPTIONAL, INT32, "b"));
+    MessageType schemaWithExtraField = new MessageType(
+        "schema",
+        new PrimitiveType(OPTIONAL, INT32, "b"),
+        new PrimitiveType(OPTIONAL, INT32, "a"),
+        new PrimitiveType(OPTIONAL, INT32, "c"));
     MemPageStore memPageStoreForOriginalSchema = new MemPageStore(1);
     MemPageStore memPageStoreForSchemaWithExtraField = new MemPageStore(1);
     SimpleGroupFactory groupFactory = new SimpleGroupFactory(orginalSchema);
-    writeGroups(orginalSchema, memPageStoreForOriginalSchema, groupFactory.newGroup().append("a", 1).append("b", 2));
+    writeGroups(
+        orginalSchema,
+        memPageStoreForOriginalSchema,
+        groupFactory.newGroup().append("a", 1).append("b", 2));
 
     SimpleGroupFactory groupFactory2 = new SimpleGroupFactory(schemaWithExtraField);
-    writeGroups(schemaWithExtraField, memPageStoreForSchemaWithExtraField, groupFactory2.newGroup().append("a", 1).append("b", 2).append("c",3));
+    writeGroups(
+        schemaWithExtraField,
+        memPageStoreForSchemaWithExtraField,
+        groupFactory2.newGroup().append("a", 1).append("b", 2).append("c", 3));
 
     {
       List<Group> groups = new ArrayList<>();
       groups.addAll(readGroups(memPageStoreForOriginalSchema, orginalSchema, schemaWithExtraField, 1));
-      groups.addAll(readGroups(memPageStoreForSchemaWithExtraField, schemaWithExtraField, schemaWithExtraField, 1));
+      groups.addAll(
+          readGroups(memPageStoreForSchemaWithExtraField, schemaWithExtraField, schemaWithExtraField, 1));
       // TODO: add once we have the support for empty projection
-//      groups1.addAll(readGroups(memPageStore3, schema3, schema2, 1));
+      //      groups1.addAll(readGroups(memPageStore3, schema3, schema2, 1));
       Object[][] expected = {
-              { 2, 1, null},
-              { 2, 1, 3},
-//          { null, null}
+        {2, 1, null},
+        {2, 1, 3},
+        //          { null, null}
       };
       validateGroups(groups, expected);
     }
   }
 
   @Test
-  public void testReadUsingRequestedSchemaWithIncompatibleField(){
-    MessageType originalSchema = new MessageType("schema",
-            new PrimitiveType(OPTIONAL, INT32, "e"));
+  public void testReadUsingRequestedSchemaWithIncompatibleField() {
+    MessageType originalSchema = new MessageType("schema", new PrimitiveType(OPTIONAL, INT32, "e"));
     MemPageStore store = new MemPageStore(1);
     SimpleGroupFactory groupFactory = new SimpleGroupFactory(originalSchema);
     writeGroups(originalSchema, store, groupFactory.newGroup().append("e", 4));
 
     try {
-      MessageType schemaWithIncompatibleField = new MessageType("schema",
-              new PrimitiveType(OPTIONAL, BINARY, "e")); // Incompatible schema: different type
+      MessageType schemaWithIncompatibleField = new MessageType(
+          "schema", new PrimitiveType(OPTIONAL, BINARY, "e")); // Incompatible schema: different type
       readGroups(store, originalSchema, schemaWithIncompatibleField, 1);
       fail("should have thrown an incompatible schema exception");
     } catch (ParquetDecodingException e) {
-      assertEquals("The requested schema is not compatible with the file schema. incompatible types: optional binary e != optional int32 e", e.getMessage());
+      assertEquals(
+          "The requested schema is not compatible with the file schema. incompatible types: optional binary e != optional int32 e",
+          e.getMessage());
     }
   }
 
   @Test
-  public void testReadUsingSchemaWithRequiredFieldThatWasOptional(){
-    MessageType originalSchema = new MessageType("schema",
-            new PrimitiveType(OPTIONAL, INT32, "e"));
+  public void testReadUsingSchemaWithRequiredFieldThatWasOptional() {
+    MessageType originalSchema = new MessageType("schema", new PrimitiveType(OPTIONAL, INT32, "e"));
     MemPageStore store = new MemPageStore(1);
     SimpleGroupFactory groupFactory = new SimpleGroupFactory(originalSchema);
     writeGroups(originalSchema, store, groupFactory.newGroup().append("e", 4));
 
     try {
-      MessageType schemaWithRequiredFieldThatWasOptional = new MessageType("schema",
-              new PrimitiveType(REQUIRED, INT32, "e")); // Incompatible schema: required when it was optional
+      MessageType schemaWithRequiredFieldThatWasOptional = new MessageType(
+          "schema",
+          new PrimitiveType(REQUIRED, INT32, "e")); // Incompatible schema: required when it was optional
       readGroups(store, originalSchema, schemaWithRequiredFieldThatWasOptional, 1);
       fail("should have thrown an incompatible schema exception");
     } catch (ParquetDecodingException e) {
-      assertEquals("The requested schema is not compatible with the file schema. incompatible types: required int32 e != optional int32 e", e.getMessage());
+      assertEquals(
+          "The requested schema is not compatible with the file schema. incompatible types: required int32 e != optional int32 e",
+          e.getMessage());
     }
   }
 
   @Test
-  public void testReadUsingProjectedSchema(){
-    MessageType orginalSchema = new MessageType("schema",
-            new PrimitiveType(REQUIRED, INT32, "a"),
-            new PrimitiveType(REQUIRED, INT32, "b")
-    );
-    MessageType projectedSchema = new MessageType("schema",
-            new PrimitiveType(OPTIONAL, INT32, "b")
-    );
+  public void testReadUsingProjectedSchema() {
+    MessageType orginalSchema = new MessageType(
+        "schema", new PrimitiveType(REQUIRED, INT32, "a"), new PrimitiveType(REQUIRED, INT32, "b"));
+    MessageType projectedSchema = new MessageType("schema", new PrimitiveType(OPTIONAL, INT32, "b"));
     MemPageStore store = new MemPageStore(1);
     SimpleGroupFactory groupFactory = new SimpleGroupFactory(orginalSchema);
     writeGroups(orginalSchema, store, groupFactory.newGroup().append("a", 1).append("b", 2));
@@ -252,7 +249,7 @@ public class TestColumnIO {
       List<Group> groups = new ArrayList<>();
       groups.addAll(readGroups(store, orginalSchema, projectedSchema, 1));
       Object[][] expected = {
-              {2},
+        {2},
       };
       validateGroups(groups, expected);
     }
@@ -268,14 +265,16 @@ public class TestColumnIO {
         if (object == null) {
           assertEquals(0, next.getFieldRepetitionCount(j));
         } else {
-          assertEquals("looking for r[" + i + "][" + j + "][0]=" + object, 1, next.getFieldRepetitionCount(j));
+          assertEquals(
+              "looking for r[" + i + "][" + j + "][0]=" + object, 1, next.getFieldRepetitionCount(j));
           assertEquals(object, next.getInteger(j, 0));
         }
       }
     }
   }
 
-  private List<Group> readGroups(MemPageStore memPageStore, MessageType fileSchema, MessageType requestedSchema, int n) {
+  private List<Group> readGroups(
+      MemPageStore memPageStore, MessageType fileSchema, MessageType requestedSchema, int n) {
     ColumnIOFactory columnIOFactory = new ColumnIOFactory(true);
     MessageColumnIO columnIO = columnIOFactory.getColumnIO(requestedSchema, fileSchema);
     RecordReaderImplementation<Group> recordReader = getRecordReader(columnIO, requestedSchema, memPageStore);
@@ -337,8 +336,14 @@ public class TestColumnIO {
         log("r" + (++i));
         log(record);
       }
-      assertEquals("deserialization does not display the same result", r1.toString(), records.get(0).toString());
-      assertEquals("deserialization does not display the same result", r2.toString(), records.get(1).toString());
+      assertEquals(
+          "deserialization does not display the same result",
+          r1.toString(),
+          records.get(0).toString());
+      assertEquals(
+          "deserialization does not display the same result",
+          r2.toString(),
+          records.get(1).toString());
     }
     {
       MessageColumnIO columnIO2 = columnIOFactory.getColumnIO(schema2);
@@ -356,8 +361,14 @@ public class TestColumnIO {
         log("r" + (++i));
         log(record);
       }
-      assertEquals("deserialization does not display the expected result", pr1.toString(), records.get(0).toString());
-      assertEquals("deserialization does not display the expected result", pr2.toString(), records.get(1).toString());
+      assertEquals(
+          "deserialization does not display the expected result",
+          pr1.toString(),
+          records.get(0).toString());
+      assertEquals(
+          "deserialization does not display the expected result",
+          pr2.toString(),
+          records.get(1).toString());
     }
   }
 
@@ -381,11 +392,7 @@ public class TestColumnIO {
   @Test
   public void testRequiredOfRequired() {
     MessageType reqreqSchema = MessageTypeParser.parseMessageType(
-          "message Document {\n"
-        + "  required group foo {\n"
-        + "    required int64 bar;\n"
-        + "  }\n"
-        + "}\n");
+        "message Document {\n" + "  required group foo {\n" + "    required int64 bar;\n" + "  }\n" + "}\n");
 
     GroupFactory gf = new SimpleGroupFactory(reqreqSchema);
     Group g1 = gf.newGroup();
@@ -401,7 +408,7 @@ public class TestColumnIO {
       for (int j = 0; j < i; j++) {
         current = new GroupType(Repetition.REQUIRED, "req" + j, current);
       }
-      MessageType groupSchema = new MessageType("schema"+i, current);
+      MessageType groupSchema = new MessageType("schema" + i, current);
       GroupFactory gf = new SimpleGroupFactory(groupSchema);
       List<Group> groups = new ArrayList<>();
       Group root = gf.newGroup();
@@ -418,7 +425,7 @@ public class TestColumnIO {
       for (int j = 0; j < i; j++) {
         current = new GroupType(Repetition.REQUIRED, "req" + j, current);
       }
-      MessageType groupSchema = new MessageType("schema"+(i+6), current);
+      MessageType groupSchema = new MessageType("schema" + (i + 6), current);
       GroupFactory gf = new SimpleGroupFactory(groupSchema);
       List<Group> groups = new ArrayList<>();
       Group rootDefined = gf.newGroup();
@@ -437,9 +444,9 @@ public class TestColumnIO {
     for (int i = 0; i < 6; i++) {
       Type current = new PrimitiveType(Repetition.OPTIONAL, PrimitiveTypeName.BINARY, "primitive");
       for (int j = 0; j < 6; j++) {
-        current = new GroupType(i==j ? Repetition.OPTIONAL : Repetition.REQUIRED, "req" + j, current);
+        current = new GroupType(i == j ? Repetition.OPTIONAL : Repetition.REQUIRED, "req" + j, current);
       }
-      MessageType groupSchema = new MessageType("schema"+(i+12), current);
+      MessageType groupSchema = new MessageType("schema" + (i + 12), current);
       GroupFactory gf = new SimpleGroupFactory(groupSchema);
       List<Group> groups = new ArrayList<>();
       Group rootDefined = gf.newGroup();
@@ -469,8 +476,7 @@ public class TestColumnIO {
 
     // Write groups.
     RecordConsumer recordWriter = columnIO.getRecordWriter(columns);
-    GroupWriter groupWriter =
-        new GroupWriter(recordWriter, messageSchema);
+    GroupWriter groupWriter = new GroupWriter(recordWriter, messageSchema);
     for (Group group : groups) {
       groupWriter.write(group);
     }
@@ -478,26 +484,26 @@ public class TestColumnIO {
     columns.flush();
 
     // Read groups and verify.
-    RecordReaderImplementation<Group> recordReader =
-        getRecordReader(columnIO, messageSchema, memPageStore);
+    RecordReaderImplementation<Group> recordReader = getRecordReader(columnIO, messageSchema, memPageStore);
     for (Group group : groups) {
       final Group got = recordReader.read();
-      assertEquals("deserialization does not display the same result",
-                   group.toString(), got.toString());
+      assertEquals("deserialization does not display the same result", group.toString(), got.toString());
     }
   }
 
-  private RecordReaderImplementation<Group> getRecordReader(MessageColumnIO columnIO, MessageType schema, PageReadStore pageReadStore) {
+  private RecordReaderImplementation<Group> getRecordReader(
+      MessageColumnIO columnIO, MessageType schema, PageReadStore pageReadStore) {
     RecordMaterializer<Group> recordConverter = new GroupRecordConverter(schema);
 
-    return (RecordReaderImplementation<Group>)columnIO.getRecordReader(pageReadStore, recordConverter);
+    return (RecordReaderImplementation<Group>) columnIO.getRecordReader(pageReadStore, recordConverter);
   }
 
   private void log(Object o) {
     LOG.info("{}", o);
   }
 
-  private void validateFSA(int[][] expectedFSA, MessageColumnIO columnIO, RecordReaderImplementation<?> recordReader) {
+  private void validateFSA(
+      int[][] expectedFSA, MessageColumnIO columnIO, RecordReaderImplementation<?> recordReader) {
     log("FSA: ----");
     List<PrimitiveColumnIO> leaves = columnIO.getLeaves();
     for (int i = 0; i < leaves.size(); ++i) {
@@ -505,8 +511,15 @@ public class TestColumnIO {
       log(Arrays.toString(primitiveColumnIO.getFieldPath()));
       for (int r = 0; r < expectedFSA[i].length; r++) {
         int next = expectedFSA[i][r];
-        log(" "+r+" -> "+ (next==leaves.size() ? "end" : Arrays.toString(leaves.get(next).getFieldPath()))+": "+recordReader.getNextLevel(i, r));
-        assertEquals(Arrays.toString(primitiveColumnIO.getFieldPath())+": "+r+" -> ", next, recordReader.getNextReader(i, r));
+        log(" " + r + " -> "
+            + (next == leaves.size()
+                ? "end"
+                : Arrays.toString(leaves.get(next).getFieldPath())) + ": "
+            + recordReader.getNextLevel(i, r));
+        assertEquals(
+            Arrays.toString(primitiveColumnIO.getFieldPath()) + ": " + r + " -> ",
+            next,
+            recordReader.getNextReader(i, r));
       }
     }
     log("----");
@@ -522,13 +535,14 @@ public class TestColumnIO {
     recordWriter.flush();
     columns.flush();
 
-    RecordReader<Void> recordReader = columnIO.getRecordReader(memPageStore, new ExpectationValidatingConverter(expectedEventsForR1, schema));
+    RecordReader<Void> recordReader =
+        columnIO.getRecordReader(memPageStore, new ExpectationValidatingConverter(expectedEventsForR1, schema));
     recordReader.read();
-
   }
 
   private ColumnWriteStoreV1 newColumnWriteStore(MemPageStore memPageStore) {
-    return new ColumnWriteStoreV1(memPageStore,
+    return new ColumnWriteStoreV1(
+        memPageStore,
         ParquetProperties.builder()
             .withPageSize(800)
             .withDictionaryPageSize(800)
@@ -551,7 +565,8 @@ public class TestColumnIO {
       recordWriter.endField("Links", 1);
       Assert.fail("expected exception because of empty field");
     } catch (ParquetEncodingException e) {
-      Assert.assertEquals("empty fields are illegal, the field should be ommited completely instead", e.getMessage());
+      Assert.assertEquals(
+          "empty fields are illegal, the field should be ommited completely instead", e.getMessage());
     }
   }
 
@@ -565,37 +580,43 @@ public class TestColumnIO {
     result.add(groupRecordConverter.getCurrentRecord());
     groupWriter.write(r2);
     result.add(groupRecordConverter.getCurrentRecord());
-    assertEquals("deserialization does not display the expected result", result.get(0).toString(), r1.toString());
-    assertEquals("deserialization does not display the expected result", result.get(1).toString(), r2.toString());
+    assertEquals(
+        "deserialization does not display the expected result",
+        result.get(0).toString(),
+        r1.toString());
+    assertEquals(
+        "deserialization does not display the expected result",
+        result.get(1).toString(),
+        r2.toString());
   }
 
   @Test
   public void testWriteWithGroupWriter() {
 
     final String[] expected = {
-        "[DocId]: 10, r:0, d:0",
-        "[Links, Forward]: 20, r:0, d:2",
-        "[Links, Forward]: 40, r:1, d:2",
-        "[Links, Forward]: 60, r:1, d:2",
-        "[Links, Backward]: null, r:0, d:1",
-        "[Name, Language, Code]: en-us, r:0, d:2",
-        "[Name, Language, Country]: us, r:0, d:3",
-        "[Name, Language, Code]: en, r:2, d:2",
-        "[Name, Language, Country]: null, r:2, d:2",
-        "[Name, Url]: http://A, r:0, d:2",
-        "[Name, Url]: http://B, r:1, d:2",
-        "[Name, Language, Code]: null, r:1, d:1",
-        "[Name, Language, Country]: null, r:1, d:1",
-        "[Name, Language, Code]: en-gb, r:1, d:2",
-        "[Name, Language, Country]: gb, r:1, d:3",
-        "[Name, Url]: null, r:1, d:1",
-        "[DocId]: 20, r:0, d:0",
-        "[Links, Backward]: 10, r:0, d:2",
-        "[Links, Backward]: 30, r:1, d:2",
-        "[Links, Forward]: 80, r:0, d:2",
-        "[Name, Url]: http://C, r:0, d:2",
-        "[Name, Language, Code]: null, r:0, d:1",
-        "[Name, Language, Country]: null, r:0, d:1"
+      "[DocId]: 10, r:0, d:0",
+      "[Links, Forward]: 20, r:0, d:2",
+      "[Links, Forward]: 40, r:1, d:2",
+      "[Links, Forward]: 60, r:1, d:2",
+      "[Links, Backward]: null, r:0, d:1",
+      "[Name, Language, Code]: en-us, r:0, d:2",
+      "[Name, Language, Country]: us, r:0, d:3",
+      "[Name, Language, Code]: en, r:2, d:2",
+      "[Name, Language, Country]: null, r:2, d:2",
+      "[Name, Url]: http://A, r:0, d:2",
+      "[Name, Url]: http://B, r:1, d:2",
+      "[Name, Language, Code]: null, r:1, d:1",
+      "[Name, Language, Country]: null, r:1, d:1",
+      "[Name, Language, Code]: en-gb, r:1, d:2",
+      "[Name, Language, Country]: gb, r:1, d:3",
+      "[Name, Url]: null, r:1, d:1",
+      "[DocId]: 20, r:0, d:0",
+      "[Links, Backward]: 10, r:0, d:2",
+      "[Links, Backward]: 30, r:1, d:2",
+      "[Links, Forward]: 80, r:0, d:2",
+      "[Name, Url]: http://C, r:0, d:2",
+      "[Name, Language, Code]: null, r:0, d:1",
+      "[Name, Language, Country]: null, r:0, d:1"
     };
 
     ValidatingColumnWriteStore columns = new ValidatingColumnWriteStore(expected);
@@ -610,6 +631,7 @@ public class TestColumnIO {
     columns.close();
   }
 }
+
 final class ValidatingColumnWriteStore implements ColumnWriteStore {
   private final String[] expected;
   int counter = 0;
@@ -619,18 +641,16 @@ final class ValidatingColumnWriteStore implements ColumnWriteStore {
   }
 
   @Override
-  public void close() {
-
-  }
+  public void close() {}
 
   @Override
   public ColumnWriter getColumnWriter(final ColumnDescriptor path) {
     return new ColumnWriter() {
-      private void validate(Object value, int repetitionLevel,
-          int definitionLevel) {
-        String actual = Arrays.toString(path.getPath())+": "+value+", r:"+repetitionLevel+", d:"+definitionLevel;
+      private void validate(Object value, int repetitionLevel, int definitionLevel) {
+        String actual = Arrays.toString(path.getPath()) + ": " + value + ", r:" + repetitionLevel + ", d:"
+            + definitionLevel;
         assertEquals("event #" + counter, expected[counter], actual);
-        ++ counter;
+        ++counter;
       }
 
       @Override
@@ -664,9 +684,7 @@ final class ValidatingColumnWriteStore implements ColumnWriteStore {
       }
 
       @Override
-      public void close() {
-
-      }
+      public void close() {}
 
       @Override
       public long getBufferedSizeInMemory() {
@@ -685,12 +703,10 @@ final class ValidatingColumnWriteStore implements ColumnWriteStore {
   }
 
   @Override
-  public void endRecord() {
-  }
+  public void endRecord() {}
 
   @Override
-  public void flush() {
-  }
+  public void flush() {}
 
   @Override
   public long getAllocatedSize() {
