@@ -18,17 +18,10 @@
  */
 package org.apache.parquet.hadoop.metadata;
 
-import org.apache.parquet.schema.MessageType;
-
 import java.io.Serializable;
-import java.util.HashMap;
 import java.util.Map;
-import java.util.Map.Entry;
-import java.util.Objects;
 import java.util.Set;
 
-import static java.util.Collections.unmodifiableMap;
-
 /**
  * Strategy to merge metadata. Possible implementations:
  * 1) Expect metadata to be exactly identical. Otherwise throw error (this is the default strategy implementation)
