@@ -1,4 +1,4 @@
-/* 
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -23,12 +23,10 @@ import org.apache.parquet.ParquetRuntimeException;
 /**
  * thrown if the schema can not be projected/filtered
  */
-
 public class ThriftProjectionException extends ParquetRuntimeException {
   private static final long serialVersionUID = 1L;
 
-  public ThriftProjectionException() {
-  }
+  public ThriftProjectionException() {}
 
   public ThriftProjectionException(String message, Throwable cause) {
     super(message, cause);
@@ -42,4 +40,3 @@ public class ThriftProjectionException extends ParquetRuntimeException {
     super(cause);
   }
 }
-
