@@ -1,4 +1,4 @@
-/* 
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,22 +18,20 @@
  */
 package org.apache.parquet.thrift.struct;
 
-
 import com.fasterxml.jackson.databind.ObjectMapper;
-import org.apache.thrift.TBase;
-import org.apache.parquet.thrift.ThriftSchemaConverter;
-
 import java.io.File;
 import java.io.IOException;
 import java.util.Arrays;
 import java.util.LinkedList;
+import org.apache.parquet.thrift.ThriftSchemaConverter;
+import org.apache.thrift.TBase;
 
 /**
  * Commandline runner for compatibility checker
- *
+ * <p>
  * java CompatibilityRunner generate-json {category_name} {class_name} {dest_dir}
  * The above command will generate json representaion of thrift schema and store it as {dest_dir}/{category_name}.json
- *
+ * <p>
  * java CompatibilityRunner compare-json {old_json_path} {new_json_path}
  * The above command will succeed when the new schema is compatible with the old schema.
  * It will fail when they are not compatible. For compatibility rules: {@link CompatibilityChecker}
@@ -43,7 +41,7 @@ public class CompatibilityRunner {
     LinkedList<String> arguments = new LinkedList<String>(Arrays.asList(args));
     String operator = arguments.pollFirst();
     if (operator.equals("generate-json")) {
-      //java CompatibilityRunner generate-json tfe_request com.twitter.logs.TfeRequestLog old_json/
+      // java CompatibilityRunner generate-json tfe_request com.twitter.logs.TfeRequestLog old_json/
       generateJson(arguments);
     }
 
@@ -79,26 +77,22 @@ public class CompatibilityRunner {
     }
 
     System.out.println("[success] schema is compatible");
-
   }
 
   private static void checkExist(File f) {
-    if (!f.exists())
-      throw new RuntimeException("can not find file " + f);
+    if (!f.exists()) throw new RuntimeException("can not find file " + f);
   }
 
-
   private static void generateJson(LinkedList<String> arguments) throws ClassNotFoundException, IOException {
     String catName = arguments.pollFirst();
     String className = arguments.pollFirst();
     String storedPath = arguments.pollFirst();
     File storeDir = new File(storedPath);
-    ThriftType.StructType structType = ThriftSchemaConverter.toStructType((Class<? extends TBase<?, ?>>) Class.forName(className));
+    ThriftType.StructType structType =
+        ThriftSchemaConverter.toStructType((Class<? extends TBase<?, ?>>) Class.forName(className));
     ObjectMapper mapper = new ObjectMapper();
 
     String fileName = catName + ".json";
     mapper.writerWithDefaultPrettyPrinter().writeValue(new File(storeDir, fileName), structType);
   }
-
-
 }
