@@ -30,21 +30,19 @@ import static org.apache.parquet.thrift.struct.ThriftTypeID.MAP;
 import static org.apache.parquet.thrift.struct.ThriftTypeID.SET;
 import static org.apache.parquet.thrift.struct.ThriftTypeID.STRING;
 import static org.apache.parquet.thrift.struct.ThriftTypeID.STRUCT;
-
-import org.apache.parquet.schema.LogicalTypeAnnotation;
-
-import java.util.Arrays;
-import java.util.HashMap;
-import java.util.Iterator;
-import java.util.List;
-import java.util.Map;
+import static org.apache.parquet.thrift.struct.ThriftTypeID.UUID;
 
 import com.fasterxml.jackson.annotation.JsonCreator;
 import com.fasterxml.jackson.annotation.JsonIgnore;
 import com.fasterxml.jackson.annotation.JsonProperty;
 import com.fasterxml.jackson.annotation.JsonSubTypes;
 import com.fasterxml.jackson.annotation.JsonTypeInfo;
-
+import java.util.Arrays;
+import java.util.HashMap;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
+import org.apache.parquet.schema.LogicalTypeAnnotation;
 
 /**
  * Descriptor for a Thrift class.
@@ -52,18 +50,19 @@ import com.fasterxml.jackson.annotation.JsonTypeInfo;
  */
 @JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.PROPERTY, property = "id")
 @JsonSubTypes({
-    @JsonSubTypes.Type(value=ThriftType.BoolType.class, name="BOOL"),
-    @JsonSubTypes.Type(value=ThriftType.ByteType.class, name="BYTE"),
-    @JsonSubTypes.Type(value=ThriftType.DoubleType.class, name="DOUBLE"),
-    @JsonSubTypes.Type(value=ThriftType.EnumType.class, name="ENUM"),
-    @JsonSubTypes.Type(value=ThriftType.I16Type.class, name="I16"),
-    @JsonSubTypes.Type(value=ThriftType.I32Type.class, name="I32"),
-    @JsonSubTypes.Type(value=ThriftType.I64Type.class, name="I64"),
-    @JsonSubTypes.Type(value=ThriftType.ListType.class, name="LIST"),
-    @JsonSubTypes.Type(value=ThriftType.MapType.class, name="MAP"),
-    @JsonSubTypes.Type(value=ThriftType.SetType.class, name="SET"),
-    @JsonSubTypes.Type(value=ThriftType.StringType.class, name="STRING"),
-    @JsonSubTypes.Type(value=ThriftType.StructType.class, name="STRUCT")
+  @JsonSubTypes.Type(value = ThriftType.BoolType.class, name = "BOOL"),
+  @JsonSubTypes.Type(value = ThriftType.ByteType.class, name = "BYTE"),
+  @JsonSubTypes.Type(value = ThriftType.DoubleType.class, name = "DOUBLE"),
+  @JsonSubTypes.Type(value = ThriftType.EnumType.class, name = "ENUM"),
+  @JsonSubTypes.Type(value = ThriftType.I16Type.class, name = "I16"),
+  @JsonSubTypes.Type(value = ThriftType.I32Type.class, name = "I32"),
+  @JsonSubTypes.Type(value = ThriftType.I64Type.class, name = "I64"),
+  @JsonSubTypes.Type(value = ThriftType.ListType.class, name = "LIST"),
+  @JsonSubTypes.Type(value = ThriftType.MapType.class, name = "MAP"),
+  @JsonSubTypes.Type(value = ThriftType.SetType.class, name = "SET"),
+  @JsonSubTypes.Type(value = ThriftType.StringType.class, name = "STRING"),
+  @JsonSubTypes.Type(value = ThriftType.StructType.class, name = "STRUCT"),
+  @JsonSubTypes.Type(value = ThriftType.UUIDType.class, name = "UUID"),
 })
 public abstract class ThriftType {
   private LogicalTypeAnnotation logicalTypeAnnotation;
@@ -135,6 +134,9 @@ public abstract class ThriftType {
 
     R visit(StringType stringType, S state);
 
+    default R visit(UUIDType uuidType, S state) {
+      throw new UnsupportedOperationException("Not implemented");
+    }
   }
 
   /**
@@ -166,54 +168,56 @@ public abstract class ThriftType {
 
     void visit(StringType stringType);
 
+    default void visit(UUIDType uuidType) {
+      throw new UnsupportedOperationException("Not implemented");
+    }
   }
 
   /**
    * @deprecated will be removed in 2.0.0.
    */
   @Deprecated
-  public static abstract class ComplexTypeVisitor implements TypeVisitor {
+  public abstract static class ComplexTypeVisitor implements TypeVisitor {
 
     @Override
-    final public void visit(EnumType enumType) {
+    public final void visit(EnumType enumType) {
       throw new IllegalArgumentException("Expected complex type");
     }
 
     @Override
-    final public void visit(BoolType boolType) {
+    public final void visit(BoolType boolType) {
       throw new IllegalArgumentException("Expected complex type");
     }
 
     @Override
-    final public void visit(ByteType byteType) {
+    public final void visit(ByteType byteType) {
       throw new IllegalArgumentException("Expected complex type");
     }
 
     @Override
-    final public void visit(DoubleType doubleType) {
+    public final void visit(DoubleType doubleType) {
       throw new IllegalArgumentException("Expected complex type");
     }
 
     @Override
-    final public void visit(I16Type i16Type) {
+    public final void visit(I16Type i16Type) {
       throw new IllegalArgumentException("Expected complex type");
     }
 
     @Override
-    final public void visit(I32Type i32Type) {
+    public final void visit(I32Type i32Type) {
       throw new IllegalArgumentException("Expected complex type");
     }
 
     @Override
-    final public void visit(I64Type i64Type) {
+    public final void visit(I64Type i64Type) {
       throw new IllegalArgumentException("Expected complex type");
     }
 
     @Override
-    final public void visit(StringType stringType) {
+    public final void visit(StringType stringType) {
       throw new IllegalArgumentException("Expected complex type");
     }
-
   }
 
   public static class StructType extends ThriftType {
@@ -221,17 +225,17 @@ public abstract class ThriftType {
 
     private final ThriftField[] childById;
 
-  /**
-   * Whether a struct is a union or a regular struct is not always known, because it was not always
-   * written to the metadata files.
-   *
-   * We should always know this in the write path, but may not in the read path.
-   */
-   public enum StructOrUnionType {
+    /**
+     * Whether a struct is a union or a regular struct is not always known, because it was not always
+     * written to the metadata files.
+     * <p>
+     * We should always know this in the write path, but may not in the read path.
+     */
+    public enum StructOrUnionType {
       STRUCT,
       UNION,
       UNKNOWN
-   }
+    }
 
     private final StructOrUnionType structOrUnionType;
 
@@ -241,8 +245,9 @@ public abstract class ThriftType {
     }
 
     @JsonCreator
-    public StructType(@JsonProperty("children") List<ThriftField> children,
-                      @JsonProperty("structOrUnionType") StructOrUnionType structOrUnionType) {
+    public StructType(
+        @JsonProperty("children") List<ThriftField> children,
+        @JsonProperty("structOrUnionType") StructOrUnionType structOrUnionType) {
       super(STRUCT);
       this.structOrUnionType = structOrUnionType == null ? StructOrUnionType.STRUCT : structOrUnionType;
       this.children = children;
@@ -304,7 +309,6 @@ public abstract class ThriftType {
       int result = childById != null ? Arrays.hashCode(childById) : 0;
       return result;
     }
-
   }
 
   public static class MapType extends ThriftType {
@@ -457,9 +461,11 @@ public abstract class ThriftType {
       this.id = id;
       this.name = name;
     }
+
     public int getId() {
       return id;
     }
+
     public String getName() {
       return name;
     }
@@ -487,7 +493,8 @@ public abstract class ThriftType {
 
   public static class EnumType extends ThriftType {
     private final List<EnumValue> values;
-    private Map<Integer,EnumValue> idEnumLookup;
+    private Map<Integer, EnumValue> idEnumLookup;
+
     @JsonCreator
     public EnumType(@JsonProperty("values") List<EnumValue> values) {
       super(ENUM);
@@ -510,9 +517,9 @@ public abstract class ThriftType {
 
     private void prepareEnumLookUp() {
       if (idEnumLookup == null) {
-        idEnumLookup=new HashMap<Integer, EnumValue>();
+        idEnumLookup = new HashMap<Integer, EnumValue>();
         for (EnumValue value : values) {
-          idEnumLookup.put(value.getId(),value);
+          idEnumLookup.put(value.getId(), value);
         }
       }
     }
@@ -554,6 +561,7 @@ public abstract class ThriftType {
     public BoolType() {
       super(BOOL);
     }
+
     @Override
     public <R, S> R accept(StateVisitor<R, S> visitor, S state) {
       return visitor.visit(this, state);
@@ -571,6 +579,7 @@ public abstract class ThriftType {
     public ByteType() {
       super(BYTE);
     }
+
     @Override
     public <R, S> R accept(StateVisitor<R, S> visitor, S state) {
       return visitor.visit(this, state);
@@ -588,6 +597,7 @@ public abstract class ThriftType {
     public DoubleType() {
       super(DOUBLE);
     }
+
     @Override
     public <R, S> R accept(StateVisitor<R, S> visitor, S state) {
       return visitor.visit(this, state);
@@ -605,6 +615,7 @@ public abstract class ThriftType {
     public I16Type() {
       super(I16);
     }
+
     @Override
     public <R, S> R accept(StateVisitor<R, S> visitor, S state) {
       return visitor.visit(this, state);
@@ -622,6 +633,7 @@ public abstract class ThriftType {
     public I32Type() {
       super(I32);
     }
+
     @Override
     public <R, S> R accept(StateVisitor<R, S> visitor, S state) {
       return visitor.visit(this, state);
@@ -645,6 +657,24 @@ public abstract class ThriftType {
       return visitor.visit(this, state);
     }
 
+    @Override
+    public void accept(TypeVisitor visitor) {
+      visitor.visit(this);
+    }
+  }
+
+  public static class UUIDType extends ThriftType {
+
+    @JsonCreator
+    public UUIDType() {
+      super(UUID);
+    }
+
+    @Override
+    public <R, S> R accept(StateVisitor<R, S> visitor, S state) {
+      this.setLogicalTypeAnnotation(LogicalTypeAnnotation.uuidType());
+      return visitor.visit(this, state);
+    }
 
     @Override
     public void accept(TypeVisitor visitor) {
@@ -694,5 +724,4 @@ public abstract class ThriftType {
   public ThriftTypeID getType() {
     return this.type;
   }
-
 }
